@@ -1,5 +1,5 @@
 __version__ = "0.0.1"
-from ._cosmic_cliffs import make_sample_data
+from ._jwst_cosmic_cliffs import make_sample_data
 
 __all__ = (
     "make_sample_data",
